Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube2015\__init__.py: 0%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube2015\__init__.py : 0%

## 3 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""

4 Supercube package with implementation for the old system version from 2015 based on

5 Siemens WinAC soft-PLC on an industrial 32bit Windows computer.

6"""

7

8 from .base import ( # noqa: F401

9 SupercubeConfiguration,

10)

11 from .typ_a import Supercube2015WithFU # noqa: F401